@@ -21,7 +21,7 @@ from zipfile import ZIP_DEFLATED, ZIP_STORED, PyZipFile, ZipFile, ZipInfo
 
 from setuptools import Distribution
 
-from cx_Freeze._compat import IS_CONDA, IS_MACOS, IS_MINGW, IS_WINDOWS
+from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS
 from cx_Freeze.common import get_resource_file_path, process_path_specs
 from cx_Freeze.exception import FileError, OptionError
 from cx_Freeze.executable import Executable
@@ -95,7 +95,8 @@ class Freezer:
         self.compress: bool = True if compress is None else compress
         self.optimize: int = int(optimize or 0)
         self.path: list[str] | None = self._validate_path(path)
-        self.include_msvcr: bool = bool(include_msvcr)
+        # include-msvcr is used on Windows, but not in MingW
+        self.include_msvcr: bool = IS_WINDOWS and bool(include_msvcr)
         self.target_dir = target_dir
         self.bin_includes: list[str] = self._validate_bin_file(bin_includes)
         self.bin_excludes: list[str] = self._validate_bin_file(bin_excludes)
@@ -678,9 +679,7 @@ class Freezer:
                         parts.append(module.file.name)
                         target_name = target_lib_dir.joinpath(*parts)
                         self._copy_file(
-                            module.file,
-                            target_name,
-                            copy_dependent_files=True,
+                            module.file, target_name, copy_dependent_files=True
                         )
                     else:
                         if module.path is not None:
@@ -756,9 +755,8 @@ class Freezer:
             )
         finder.add_constant("_EXECUTABLES_NUMBER", len(self.executables))
 
-        # Write the modules baefore the included files to fix an issue
-        if IS_WINDOWS and not IS_CONDA:
-            self._write_modules()
+        # Write the modules
+        self._write_modules()
 
         # Include user-defined files and hooks-defined files
         target_dir = self.target_dir
@@ -786,10 +784,6 @@ class Freezer:
                 fulltarget = target_dir / target_path
                 self._copy_file(source_path, fulltarget, copy_dependent_files)
 
-        # Write the modules after the included files to avoid duplicate files
-        if not (IS_WINDOWS and not IS_CONDA):
-            self._write_modules()
-
         # do any platform-specific post-Freeze work
         self._post_freeze_hook()
 
